@@ -33,9 +33,10 @@
 #  define KNTLM_DEPRECATED_NO_EXPORT KNTLM_NO_EXPORT KNTLM_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KNTLM_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KNTLM_NO_DEPRECATED
+#    define KNTLM_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
